# COPR Ligenix's spec file for glpi-plugin-pdf
#
# Copyright (c) 2021-2022 Jean-Marc Liger 
#
# Forked from:
#
# remirepo spec file for glpi-pdf
#
# Copyright (c) 2007-2020 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global pluginname pdf
%global glpi_min   10.0.0
%global glpi_max   10.1.0


Name:           glpi-plugin-%{pluginname}
Version:        3.0.0
Release:        1%{?dist}
Summary:        GLPI Plugin to print PDF of equipment
Summary(fr):    Extension GLPI pour créer des PDF des matériels

License:        GPLv2+
URL:            https://github.com/yllen/%{pluginname}

Source0:        https://github.com/yllen/%{pluginname}/releases/download/v%{version}/glpi-%{pluginname}-%{version}.tar.gz

BuildArch:      noarch
BuildRequires:  gettext

Requires:       php-intl
%if 0%{?fedora} || 0%{?rhel} >= 8
Requires:      (glpi >= %{glpi_min} with glpi < %{glpi_max})
%else
Requires:       glpi >= %{glpi_min}
Requires:       glpi <  %{glpi_max}
%endif
Provides:       glpi-%{pluginname} = %{version}-%{release}
Obsoletes:      glpi-%{pluginname} <= 1.6.1


%description
This GLPI plugin enables you to print, in pdf format, the information 
sheet of an equipment or a software of the inventory. 


%description -l fr
Cette extension GLPI vous permet de créer un PDF contenant toutes les
informations sur un équipement ou un logiciel de l'inventaire.


%prep
%setup -q -c

# update forge URL
find -type f -name "*.php" -exec sed -i 's/forge.glpi-project.org\/projects/github.com\/yllen/g' {} +

# remove unused files
rm    %{pluginname}/%{pluginname}.xml
rm    %{pluginname}/composer.*
 
# create link to LICENSE for standard doc folder
ln -s %{_datadir}/glpi/plugins/%{pluginname}/LICENSE LICENSE


%build
# regenerate the locales
for po in %{pluginname}/locales/*.po
do
   msgfmt $po -o $(dirname $po)/$(basename $po .po).mo
done


%install
mkdir -p %{buildroot}/%{_datadir}/glpi/plugins
cp -ar %{pluginname} %{buildroot}/%{_datadir}/glpi/plugins/%{pluginname}

for i in %{buildroot}/%{_datadir}/glpi/plugins/%{pluginname}/locales/*
do
  lang=$(basename $i)
  echo "%lang(${lang:0:2}) %{_datadir}/glpi/plugins/%{pluginname}/locales/${lang}"
done | tee %{name}.lang



%files -f %{name}.lang
%{!?_licensedir:%global license %%doc}
%license LICENSE
%dir %{_datadir}/glpi/plugins/%{pluginname}
%dir %{_datadir}/glpi/plugins/%{pluginname}/locales
# LICENSE file required by installation process
%{_datadir}/glpi/plugins/%{pluginname}/LICENSE
%{_datadir}/glpi/plugins/%{pluginname}/%{pluginname}.png
%{_datadir}/glpi/plugins/%{pluginname}/*.php
%{_datadir}/glpi/plugins/%{pluginname}/fonts
%{_datadir}/glpi/plugins/%{pluginname}/front
%{_datadir}/glpi/plugins/%{pluginname}/inc
%{_datadir}/glpi/plugins/%{pluginname}/pics
%{_datadir}/glpi/plugins/%{pluginname}/vendor


%changelog
* Fri Nov 18 2022 Jean-Marc Liger <ligenix@iscp.fr> - 3.0.0-1
- version 3.0.0 for GLPI 10.0.x

* Sat Sep 17 2022 Jean-Marc Liger <ligenix@iscp.fr> - 2.1.0-3
- update forge URL

* Sun Sep 11 2022 Jean-Marc Liger <ligenix@iscp.fr> - 2.1.0-2
- add missing vendor directory

* Fri Jul 29 2022 Jean-Marc Liger <ligenix@iscp.fr> - 2.1.0-1
- version 2.1.0 for GLPI 10.0.x

* Fri Jul 29 2022 Jean-Marc Liger <ligenix@iscp.fr> - 2.0.0-3
- new github source
  https://github.com/yllen/pdf/wiki

* Mon May 17 2021 Jean-Marc Liger <ligenix@iscp.fr> - 2.0.0-2
- update spec file's copyright, thanks again to Remy Collet!

* Mon Apr 12 2021 Jean-Marc Liger <ligenix@iscp.fr> - 2.0.0-1
- rename to glpi-plugin-pdf
- version 2.0.0 for GLPI >= 9.5.4
  https://forge.glpi-project.org/versions/1315

* Wed Aug 26 2020 Remi Collet <remi@remirepo.net> - 1.6.1-1
- version 1.6.1 for GLPI >= 9.4
  https://forge.glpi-project.org/versions/1303

* Sat Jul 13 2019 Remi Collet <remi@remirepo.net> - 1.6.0-1
- version 1.6.0 for GLPI >= 9.4

* Fri Apr 26 2019 Remi Collet <remi@remirepo.net> - 1.5.0-1
- version 1.5.0 for GLPI >= 9.3
  https://forge.glpi-project.org/versions/1277

* Tue Dec  4 2018 Remi Collet <remi@remirepo.net> - 1.4.0-2
- add missing dependency on php-intl

* Thu Sep 13 2018 Remi Collet <remi@remirepo.net> - 1.4.0-1
- version 1.4.0 for GLPI >= 9.3
  https://forge.glpi-project.org/versions/1273

* Wed Feb 28 2018 Remi Collet <remi@remirepo.net> - 1.3.1.1-1
- version 1.3.1.1 for GLPI >= 9.2

* Wed Feb 28 2018 Remi Collet <remi@remirepo.net> - 1.3.1-1
- version 1.3.1 for GLPI >= 9.2
  https://forge.glpi-project.org/versions/1260
- open https://forge.glpi-project.org/issues/5550 - missing file

* Fri Nov  3 2017 Remi Collet <remi@remirepo.net> - 1.3.0-1
- version 1.3.0 for GLPI >= 9.2
  https://forge.glpi-project.org/versions/1248

* Tue Oct 24 2017 Remi Collet <remi@remirepo.net> - 1.2-1
- version 1.2 for GLPI >= 9.1

* Mon Jan  9 2017 Remi Collet <remi@fedoraproject.org> - 1.1-1
- version 1.1 for GLPI >= 9.1
  https://forge.glpi-project.org/versions/1216
- require glpi 9.1.1-3 for tcpdf autoloader

* Mon Jan  9 2017 Remi Collet <remi@fedoraproject.org> - 1.0.3-1
- version 1.0.3 for GLPI >= 0.85.3
  https://forge.glpi-project.org/versions/1219

* Tue Jun 28 2016 Johan Cwiklinski <jcwiklinski AT teclib DOT com> - 1.0.2-1.1
- Change URL

* Mon May 30 2016 Remi Collet <remi@fedoraproject.org> - 1.0.2-1
- version 1.0.2 for GLPI >= 0.85.3
  https://forge.glpi-project.org/versions/1199

* Fri Apr 15 2016 Remi Collet <remi@fedoraproject.org> - 1.0.1-1
- version 1.0.1 for GLPI >= 0.85.3
  https://forge.glpi-project.org/versions/1193

* Fri Feb 26 2016 Remi Collet <remi@fedoraproject.org> - 1.0-1
- version 1.0 for GLPI >= 0.85.3
  https://forge.glpi-project.org/versions/1178

* Sun Jun  8 2014 Remi Collet <remi@fedoraproject.org> - 0.84.2-1
- version 0.84.2
  https://forge.indepnet.net/versions/1043

* Thu Apr 17 2014 Remi Collet <remi@fedoraproject.org> - 0.84.1-1
- version 0.84.1
  https://forge.indepnet.net/projects/pdf/versions/1019

* Wed Feb 12 2014 Remi Collet <remi@fedoraproject.org> - 0.84-1
- version 0.84 for GLPI 0.84
  https://forge.indepnet.net/projects/pdf/versions/941

* Thu Apr 19 2012 Remi Collet <Fedora@FamilleCollet.com> - 0.83-2
- add patch for 0.83.1 (Problem tab on various object)

* Fri Apr 06 2012 Remi Collet <Fedora@FamilleCollet.com> - 0.83-1
- version 0.83
  https://forge.indepnet.net/projects/pdf/versions/615

* Sun Feb 26 2012 Remi Collet <Fedora@FamilleCollet.com> - 0.83-0.1.svn315
- update to 0.83 for glpi 0.83 RC (svn snapshot)

* Tue Sep 20 2011 Remi Collet <Fedora@FamilleCollet.com> - 0.80.3-1
- version 0.80.3
  https://forge.indepnet.net/projects/pdf/versions/617

* Tue Jul 19 2011 Remi Collet <Fedora@FamilleCollet.com> - 0.80-1
- update to 0.80 (version have change from 0.8.0)

* Tue Jun 28 2011 Remi Collet <Fedora@FamilleCollet.com> - 0.8.0-0.1.svn259
- update to 0.8.0 for glpi 0.80 RC (svn snapshot)

* Sat Jun 11 2011 Remi Collet <Fedora@FamilleCollet.com> - 0.7.2-1
- version 0.7.2
  https://forge.indepnet.net/projects/pdf/versions/550

* Sat Jan 22 2011 Remi Collet <Fedora@FamilleCollet.com> - 0.7.1-1
- version 0.7.1

* Tue Oct 12 2010 Remi Collet <Fedora@FamilleCollet.com> - 0.7.0-1
- version 0.7.0 and GLPI 0.78 released

* Sat Sep 18 2010 Remi Collet <Fedora@FamilleCollet.com> - 0.7.0-0.1.svn194
- new snapshot

* Tue Aug 10 2010 Remi Collet <Fedora@FamilleCollet.com> - 0.7.0-0.1.svn190
- new snapshot

* Thu Jul 08 2010 Remi Collet <Fedora@FamilleCollet.com> - 0.7.0-0.1.svn189
- new snapshot

* Tue Jun 15 2010 Remi Collet <Fedora@FamilleCollet.com> - 0.7.0-0.1.svn188
- update to 0.7.0 for glpi 0.78 RC (svn snapshot)

* Fri May 21 2010 Remi Collet <Fedora@FamilleCollet.com> - 0.6.1-2
- spec cleanup

* Tue Aug 18 2009 Remi Collet <Fedora@FamilleCollet.com> - 0.6.1-1
- update to 0.6.1 finale for glpi 0.72

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Jul 12 2008 Remi Collet <Fedora@FamilleCollet.com> - 0.5-1
- update to 0.5 finale for glpi 0.71

* Thu Dec 27 2007 Remi Collet <Fedora@FamilleCollet.com> - 0.4-1
- update to 0.4 finale
- Initial RPM for Fedora review

* Sun Nov 11 2007 Remi Collet <RPMS@FamilleCollet.com> - 0.4-0.20071111
- update from SVN

* Sun Sep 23 2007 Remi Collet <RPMS@FamilleCollet.com> - 0.3-0.20070922
- new SVN snapshot

* Mon Aug 13 2007 Remi Collet <RPMS@FamilleCollet.com> - 0.2-0.20070813
- Initial RPM

